summaryrefslogtreecommitdiff
path: root/subversion/include/svn_xml.h
diff options
context:
space:
mode:
Diffstat (limited to 'subversion/include/svn_xml.h')
-rw-r--r--subversion/include/svn_xml.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/subversion/include/svn_xml.h b/subversion/include/svn_xml.h
index 90969be..8791b14 100644
--- a/subversion/include/svn_xml.h
+++ b/subversion/include/svn_xml.h
@@ -312,7 +312,7 @@ svn_xml_make_header(svn_stringbuf_t **str,
* If @a *str is @c NULL, set @a *str to a new stringbuf allocated
* in @a pool, else append to the existing stringbuf there.
*
* Take the tag's attributes from varargs, a NULL-terminated list of
* alternating <tt>char *</tt> key and <tt>char *</tt> val. Do xml-escaping
* on each val.
*
@@ -323,7 +323,7 @@ svn_xml_make_open_tag(svn_stringbuf_t **str,
apr_pool_t *pool,
enum svn_xml_open_tag_style style,
const char *tagname,
- ...);
+ ...) SVN_NEEDS_SENTINEL_NULL;
/** Like svn_xml_make_open_tag(), but takes a @c va_list instead of being
@@ -312,7 +312,7 @@ svn_xml_make_header(svn_stringbuf_t **str,
* in @a pool, else append to the existing stringbuf there.
*
- * Take the tag's attributes from varargs, a NULL-terminated list of
+ * Take the tag's attributes from varargs, a SVN_VA_NULL-terminated list of
* alternating <tt>char *</tt> key and <tt>char *</tt> val. Do xml-escaping
* on each val.